Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2429)

Unified Diff: chrome/common/chrome_switches.cc

Issue 10689016: Revert 144170 - Merge 144108 - [Sync] Disable search engines datatype by default. (Closed) Base URL: svn://svn.chromium.org/chrome/branches/1132_43/src/
Patch Set: Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/common/chrome_switches.h ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/common/chrome_switches.cc
===================================================================
--- chrome/common/chrome_switches.cc (revision 144576)
+++ chrome/common/chrome_switches.cc (working copy)
@@ -393,8 +393,8 @@
// Disables syncing of preferences.
const char kDisableSyncPreferences[] = "disable-sync-preferences";
-// Enable syncing custom search engines.
-const char kEnableSyncSearchEngines[] = "enable-sync-search-engines";
+// Disable syncing custom search engines.
+const char kDisableSyncSearchEngines[] = "disable-sync-search-engines";
// Disables syncing of themes.
const char kDisableSyncThemes[] = "disable-sync-themes";
« no previous file with comments | « chrome/common/chrome_switches.h ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698